# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import test_hr_employee
from . import test_channel
from . import test_self_user_access
from . import test_multi_company
from . import test_resource
from . import test_ui
